[−][src]Module solstice::buffer
Structs
| Buffer | A memory map between a CPU and GPU buffer. |
| Mapped | |
| ModifiedRange |
Enums
| BufferType | Used to inform the implementation of how it should be bound. |
| Usage | Used to hint to the implementation how frequently the user will be changing the buffer's data. |
Type Definitions
| MappedBuffer |