pub enum Usage {
Stream,
Static,
Dynamic,
}Expand description
Used to hint to the implementation how frequently the user will be changing the buffer’s data.
Static: The user will set the data once.Dynamic: The user will set the data occasionally.Stream: The user will be changing the data after every use. Or almost every use.
Variants
Implementations